# Step 7: Track and Report
### On this page
  * [Use Application Rationalization Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report#use-application-rationalization-dashboard)
  * [Optional: Create a Custom Application Rationalization Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report#optional:-create-a-custom-application-rationalization-dashboard)
  * [Configure the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report#configure-the-architecture-executive-dashboard)


Track application rationalization progress, share insightful reports with stakeholders, and demonstrate ongoing value using tailored dashboards and key performance indicators.
This brings you to the final, but vital, step in your journey. To have continuous support for the application rationalization tell a compelling story to affected stakeholders and management. SAP LeanIX dashboards are a handy tool to support your story with data points. By combining different KPIs and reports, you backup your story and show continuous progress.
Explore the different options and find your best toolkit for tracking and reporting:
  * [Use Application Rationalization Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD#loio275d6c6f7a441014af49fbca7532cc3c__Use-Application-Rationalization-Dashboard)
  * [Optional: Create a Custom Application Rationalization Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD#loio275d6c6f7a441014af49fbca7532cc3c__Optional_-Create-a-Custom-Application-Rationalization-Dashboard)
  * [Configure the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD#loio275d6c6f7a441014af49fbca7532cc3c__Use-Architecture-Executive-Dashboard)
